==> clean900_1.1.2-6.tar.gz: clean900-1.1.2/usr/bin/clean900/clean900-en.sh <==
#!/bin/sh
#Clean900
#version 1.1.2
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

source /usr/bin/clean900/funclean-en.sh

gest=`ps ux |grep -c hildon-application-manager`

if [ $gest = 3 ]
	then
		quest=$(gestoreaperto;echo $?)

	else
		quest=0
fi

if [ $quest -eq 0 ]
	then
		killappman
		inputline=$(primostep --separator=":")
		IFS=":"
		for prova in $inputline; do
		case $prova in

			"clean")clean;;

			"autoclean")autoclean;;

			"autoremove")autoremove;;

			"purge")purge;;

			"Update")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
				if [ "$conn" != "1" ]
					then
						ric=`ricconn;echo $?`
						if [ "$ric" = 0 ]
							then
								connessione
								update
							else
								popup_ann
						fi
					else
						update
				fi;;

			"Upgrade")
				res=$(echo "n" | apt-get upgrade )
				if [ $? -eq 1 ]; then
					if zenity --title=Clean900 --question --text "$res"; then
						res=$(apt-get upgrade -f -y --force-yes)
						aggiornamenti
						else
							noaggiornamenti
					fi
				fi
					zenity --title=Clean900 --info --text "$res";;

				"Applications") 
						choice=$(applicazioni --separator=":");
						case $choice in
	
				"Create backup of your applications")
					mkdir /home/user/MyDocs/clean900/ > \/tmp\/output.txt 2> \/dev\/null
					ricback=`zenity --warning --title CleaN900 --text "Are you sure you want to create a backup file? If you want to create it, choose OK, otherwise step into the void";echo $?`
					if [ "$ricback" -eq 0 ]
						then
						nomefile=`zenity --entry --text="Enter the name of the backup" --entry-text="es. backup_01-01-11"` && \
							dpkg --get-selections > /home/user/MyDocs/clean900/$nomefile.txt
							backupcreato
						else
							popup_ann
					fi;;

				"Restore from backup applications")
						conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
							if [ "$conn" != "1" ]
								then
									ric=`ricconn;echo $?`
										if [ "$ric" = 0 ]
											then
												connessione
						ricrip=`zenity --warning --title CleaN900 --text "Are you sure you want to restore a backup file? If you want to restore click OK , otherwise step into the void";echo $?`
						if [ "$ricrip" -eq 0 ]
							then
								backup=`selbackup` && dpkg --set-selections < $backup
								opincorso
								res=$(echo "n" | apt-get dselect-upgrade )
									if [ $? -eq 1 ]; then
										if zenity --title=Clean900 --question --text "$res"; then
											res=$(apt-get dselect-upgrade -f -y --force-yes)
											ripristino
										else
											popup_ann
										fi
									fi
										zenity --title=Clean900 --info --text "$res"
							else
								popup_ann
						fi
											else
												popup_ann
										fi
							fi;;

				"Install a package .deb")
					pacchetto=`seldeb`
					if [ $? -eq 0 ]; then
						dpkg -i $pacchetto | zenity --progress --pulsate --title="Install" --text="Wait for the loading bar"
						paccinst
						else
							popup_ann
					fi;;				

				"Remove specific package")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
						if [ "$conn" != "1" ]
							then
								ric=`ricconn;echo $?`
									if [ "$ric" = 0 ]
										then
											connessione
											pacchetto=`rempac`
											dpkg -r $pacchetto | waitdis
											paccdis
										else
											popup_ann
									fi
							else
								pacchetto=`rempac`
									if [ $? -eq 0 ]; then
										dpkg -r $pacchetto | waitdis
										paccdis
										else
											popup_ann
									fi
						fi;;

				"Reboot")riavvio;;
			esac
			;;

		"Reboot")riavvio;;

esac
done
	else
		popup_ann
fi

==> clean900_1.1.2-9.tar.gz: clean900-1.1.2/usr/bin/clean900/clean900-en.sh <==
#!/bin/sh
#Clean900
#version 1.1.2
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

source /usr/bin/clean900/funclean-en.sh

gest=`ps ux |grep -c hildon-application-manager`

if [ $gest = 3 ]
	then
		quest=$(gestoreaperto;echo $?)

	else
		quest=0
fi

if [ $quest -eq 0 ]
	then
		killappman
		inputline=$(primostep --separator=":")
		IFS=":"
		for prova in $inputline; do
		case $prova in

			"clean")clean;;

			"autoclean")autoclean;;

			"autoremove")autoremove;;

			"purge")purge;;

			"Update")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
				if [ "$conn" -ne "0" ]
					then
						ric=`ricconn;echo $?`
						if [ "$ric" = 0 ]
							then
								connessione
								update
							else
								popup_ann
						fi
					else
						update
				fi;;

			"Upgrade")
				res=$(echo "n" | apt-get upgrade )
				if [ $? -eq 1 ]; then
					if zenity --title=Clean900 --question --text "$res"; then
						res=$(apt-get upgrade -f -y --force-yes)
						aggiornamenti
						else
							noaggiornamenti
					fi
				fi
					zenity --title=Clean900 --info --text "$res";;

				"Applications") 
						choice=$(applicazioni --separator=":");
						case $choice in
	
				"Create backup of your applications")
					mkdir /home/user/MyDocs/clean900/ > \/tmp\/output.txt 2> \/dev\/null
					ricback=`zenity --warning --title CleaN900 --text "Are you sure you want to create a backup file? If you want to create it, choose OK, otherwise step into the void";echo $?`
					if [ "$ricback" -eq 0 ]
						then
						nomefile=`zenity --entry --text="Enter the name of the backup" --entry-text="es. backup_01-01-11"` && \
							dpkg --get-selections > /home/user/MyDocs/clean900/$nomefile.txt
							backupcreato
						else
							popup_ann
					fi;;

				"Restore from backup applications")
						conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
							if [ "$conn" -ne "0" ]
								then
									ric=`ricconn;echo $?`
										if [ "$ric" = 0 ]
											then
												connessione
						ricrip=`zenity --warning --title CleaN900 --text "Are you sure you want to restore a backup file? If you want to restore click OK , otherwise step into the void";echo $?`
						if [ "$ricrip" -eq 0 ]
							then
								backup=`selbackup` && dpkg --set-selections < $backup
								opincorso
								res=$(echo "n" | apt-get dselect-upgrade )
									if [ $? -eq 1 ]; then
										if zenity --title=Clean900 --question --text "$res"; then
											res=$(apt-get dselect-upgrade -f -y --force-yes)
											ripristino
										else
											popup_ann
										fi
									fi
										zenity --title=Clean900 --info --text "$res"
							else
								popup_ann
						fi
											else
												popup_ann
										fi
							fi;;

				"Install a package .deb")
					pacchetto=`seldeb`
					if [ $? -eq 0 ]; then
						dpkg -i $pacchetto | zenity --progress --pulsate --title="Install" --text="Wait for the loading bar"
						paccinst
						else
							popup_ann
					fi;;				

				"Remove specific package")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
						if [ "$conn" -ne "0" ]
							then
								ric=`ricconn;echo $?`
									if [ "$ric" = 0 ]
										then
											connessione
											pacchetto=`rempac`
											dpkg -r $pacchetto | waitdis
											paccdis
										else
											popup_ann
									fi
							else
								pacchetto=`rempac`
									if [ $? -eq 0 ]; then
										dpkg -r $pacchetto | waitdis
										paccdis
										else
											popup_ann
									fi
						fi;;

				"Reboot")riavvio;;
			esac
			;;

		"Reboot")riavvio;;

esac
done
	else
		popup_ann
fi
